/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.usermgt;

import org.wamblee.security.encryption.MessageDigester;
import static org.wamblee.usermgt.UserMgtException.Reason.DUPLICATE_USER;

/**
 * User set base class.
 */
public abstract class AbstractUserSet implements UserSet {
    /**
     * Password validator.
     */
    private NameValidator passwordValidator;

    /**
     * Password encoder.
     */
    private MessageDigester passwordEncoder;

    /**
     * Creates a new AbstractUserSet object.
     * 
     */
    protected AbstractUserSet(NameValidator aPasswordValidator,
        MessageDigester aPasswordEncoder) {
        passwordValidator = aPasswordValidator;
        passwordEncoder = aPasswordEncoder;
    }

    /**
     * Sets the password validtor and encoder in the user.
     * 
     * @param aUser
     *            User.
     */
    protected void setPasswordInfo(User aUser) {
        aUser.setPasswordValidator(passwordValidator);
        aUser.setPasswordEncoder(passwordEncoder);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.UserSet#createUser(java.lang.String,
     * java.lang.String, org.wamblee.usermgt.Group)
     */
    public User createUser(String aUsername, String aPassword, Group aGroup)
        throws UserMgtException {
        User user = new User(aUsername, aPassword, aGroup, passwordValidator,
            passwordEncoder);

        if (contains(user)) {
            throw new UserMgtException(DUPLICATE_USER, user);
        }

        add(user);

        return user;
    }
}
