/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.usermgt;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;
import java.util.concurrent.atomic.AtomicLong;

/**
 * In-memory group set implementation.
 * 
 * @author Erik Brakkee
 */
public class InMemoryGroupSet implements GroupSet {

    private AtomicLong pk = new AtomicLong(1l);

    /**
     * Groups.
     */
    private List<Group> groups;

    /**
     * Constructs an empty group set.
     */
    public InMemoryGroupSet() {
        groups = new ArrayList<Group>();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.wamblee.usermgt.GroupSet#groupModified(org.wamblee.usermgt.Group)
     */
    public void groupModified(Group aGroup) {
        for (int i = 0; i < groups.size(); i++) {
            if (groups.get(i).getPrimaryKey().equals(aGroup.getPrimaryKey())) {
                groups.remove(i);
                groups.add(aGroup);
                return;
            }
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#find(java.lang.String)
     */
    public Group find(String aName) {
        for (Group group : groups) {
            if (group.getName().equals(aName)) {
                return group;
            }
        }

        return null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#contains(org.wamblee.usermgt.Group)
     */
    public boolean contains(Group aGroup) {
        return groups.contains(aGroup);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#add(org.wamblee.usermgt.Group)
     */
    public boolean add(Group aGroup) {
        aGroup.setPrimaryKey(pk.getAndIncrement());
        if (find(aGroup.getName()) != null) {
            return false;
        }
        return groups.add(aGroup);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#remove(org.wamblee.usermgt.Group)
     */
    public boolean remove(Group aGroup) {
        return groups.remove(aGroup);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#list()
     */
    public Set<Group> list() {
        Set<Group> list = new TreeSet<Group>();

        for (Group group : groups) {
            list.add(new Group(group));
        }

        return list;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.usermgt.GroupSet#size()
     */
    public int size() {
        return groups.size();
    }
}
